pub fn wait_for_git_lock<P: AsRef<Path>>(path: P) -> Result<(), GitError>Expand description
Wait for a git lock to be released with exponential backoff.
Returns Ok(()) if the lock is released within the retry window,
or Err(GitError::RepositoryLocked) if it times out.